@@ -5,10 +5,9 @@ import matplotlib as mpl
 import matplotlib.pyplot as plt
 
 # Project import(s)
-from . import style
+import theme
 
 # Decorators
-print("importing style")
 
 
 def defer(func):
@@ -32,16 +31,15 @@ class figure:
 
     # Constructor
     def __init__(self, dark=False, despine=0):
-
         # Member variables
         self._dark = dark
         self._despine = despine  # @TODO: axis label padding not workign properly with despine
-        reload(style.theme)
+        reload(theme)
         if self._dark:
             self._make_dark()
             pass
         reload(plt)
-        self._base = plt.figure(facecolor=style.base if self._dark else None)
+        self._base = plt.figure(facecolor=theme.base if self._dark else None)
 
         # State
         self._styled = False
@@ -65,7 +63,7 @@ class figure:
         inset = self._base.add_axes([box.x0, box.y0 + box.height + 0.022, box.width,
                                     box.height * 0.09], anchor='NE', frameon=False, xticks=[], yticks=[])
         inset.imshow(
-            style.images['normal' if self._dark else 'inverted'], interpolation='none', alpha=alpha)
+            theme.images['normal' if self._dark else 'inverted'], interpolation='none', alpha=alpha)
         return
 
     # Specialised, deferred methods
@@ -78,7 +76,7 @@ class figure:
             'va': 'bottom',
             'x': 0.00,
             'y': 1.02,
-            'fontdict': {'family': 'serif', 'weight': 'bold', 'size': 14, "color": 'white' if self._dark else style.base}
+            'fontdict': {'family': 'serif', 'weight': 'bold', 'size': 14, "color": 'white' if self._dark else theme.base}
         }
         kwargs = dict(defaults, **kwargs)
 
@@ -203,7 +201,7 @@ class figure:
         mpl.rcParams['ytick.color'] = 'white'
         mpl.rcParams['text.color'] = 'white'
         mpl.rcParams['axes.prop_cycle'] = mpl.cycler(
-            color=['white'] + style.colours[1:])
+            color=['white'] + theme.colours[1:])
         return
 
     def _add_padding(self, top=0, bottom=0, left=0, right=0, ax=None):
@@ -252,7 +250,7 @@ class figure:
         ax.xaxis.get_major_locator().set_params(nbins=5, steps=[1, 2, 5, 10])
         ax.yaxis.get_major_locator().set_params(nbins=5, steps=[1, 2, 5, 10])
         if self._dark:
-            ax.set_facecolor(style.base)
+            ax.set_facecolor(theme.base)
             pass
         sns.despine(offset=self._despine)
         return
